@@ -1,5 +1,5 @@
 package Util::Medley::File;
-$Util::Medley::File::VERSION = '0.018';
+$Util::Medley::File::VERSION = '0.019';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -22,7 +22,7 @@ Util::Medley::File - utility file methods
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =cut
 
@@ -443,9 +443,11 @@ multi method findFiles (Str :$dir!,
 	
 	foreach my $path (@paths) {	
 		next if -d $path;
-	
-		if ($extension and $path =~ /\.$extension$/) {
-			push @files, $path;	
+		
+		if ($extension) {
+			if ($path =~ /\.$extension$/) {
+				push @files, $path;	
+			}
 		}
 		else {	
 			push @files, $path;	
